@@ -156,9 +156,8 @@ LDVWidget::LDVWidget(QWidget *parent, IniFlag iniflag, bool forceIni)
 	iniFiles[LDViewPOVIni]	 = { iniFlagNames[LDViewPOVIni],   Preferences::ldviewPOVIni };
 	iniFiles[LDViewIni]		 = { iniFlagNames[LDViewIni],	   Preferences::ldviewIni };
 
-	setupLDVFormat();
-
 #if (QT_VERSION < 0x50400)
+	setupLDVFormat();
 	setupLDVContext();
 #endif
 
@@ -166,7 +165,7 @@ LDVWidget::LDVWidget(QWidget *parent, IniFlag iniflag, bool forceIni)
 		return;
 
 	const QString ldvMessages = QDir::toNativeSeparators(QString("%1%2")
-												  .arg(Preferences::dataLocation, VER_LDVMESSAGESINI_FILE));
+														 .arg(Preferences::dataLocation, VER_LDVMESSAGESINI_FILE));
 	if (!TCLocalStrings::loadStringTable(copyString(ldvMessages.toUtf8().constData())))
 		emit lpub->messageSig(LOG_ERROR,
 							  QString::fromWCharArray(TCLocalStrings::get(L"LoadLDVMessagesError")).arg(ldvMessages));
@@ -183,15 +182,24 @@ LDVWidget::LDVWidget(QWidget *parent, IniFlag iniflag, bool forceIni)
 
 	setSession();
 
+	char *path = nullptr;
 	if (!Preferences::ldrawLibPath.isEmpty())
 	{
-		const char *path = copyString(Preferences::ldrawLibPath.toUtf8().constData());
-		TCUserDefaults::setStringForKey(path, LDRAWDIR_KEY, false);
+		path = copyString(Preferences::ldrawLibPath.toUtf8().data());
 	}
-	if (!Preferences::lpub3dLibFile.isEmpty())
+	if (QFileInfo::exists(path))
 	{
-		const char *path = copyString(Preferences::lpub3dLibFile.toUtf8().constData());
-		TCUserDefaults::setStringForKey(path, LDRAWZIP_KEY, false);
+		TCUserDefaults::setStringForKey(path, LDRAWDIR_KEY, false);
+		path = copyString(QString("%1%2complete.zip").arg(path,QDir::separator()).toUtf8().constData());
+		if (QFileInfo::exists(path))
+		{
+			TCUserDefaults::setStringForKey(path, LDRAWZIP_KEY, false);
+		}
+		else if (!Preferences::lpub3dLibFile.isEmpty())
+		{
+			path = copyString(Preferences::lpub3dLibFile.toUtf8().constData());
+			TCUserDefaults::setStringForKey(path, LDRAWZIP_KEY, false);
+		}
 	}
 
 	ldvWidget = this;
@@ -254,6 +262,8 @@ bool LDVWidget::setupLDVApplication()
 		return false;
 	}
 
+	modelViewer->setAppVersion(LDV_VERSION);
+
 	ldPrefs = new LDPreferences(modelViewer);
 
 	setSession(true/*savedSession*/);
@@ -427,16 +437,24 @@ bool LDVWidget::doCommand(QStringList &arguments)
 
 	setStudLogo();
 
-	bool retValue = true;
+	bool exportFile = false;
+
+	static const QRegularExpression rx("^.*-ExportFile=.*$", QRegularExpression::CaseInsensitiveOption);
+
+	if (arguments.indexOf(rx, 0) != -1)
+	{
+		exportFile = true;
+		if (!setupLDVApplication())
+			return false;
+	}
 
 	if (!LDSnapshotTaker::doCommandLine(false, true))
 	{
-		static const QRegularExpression rx("^.*-ExportFile=.*$", QRegularExpression::CaseInsensitiveOption);
-		if ((arguments.indexOf(rx, 0) != -1))
+		if (exportFile)
 		{
 			emit lpub->messageSig(LOG_ERROR,
 								  QString::fromWCharArray(TCLocalStrings::get(L"ExportCommandError")).arg(arguments.join(" ")));
-			retValue = false;
+			return false;
 		}
 		else
 		if (iniFlag == NativePartList)
@@ -454,7 +472,7 @@ bool LDVWidget::doCommand(QStringList &arguments)
 
 	commandLineSnapshotSave = (snapshotFilename ? true : false);
 
-	return retValue;
+	return true;
 }
 
 bool LDVWidget::getUseFBO()
@@ -468,12 +486,8 @@ bool LDVWidget::getUseFBO()
 
 void LDVWidget::setupLDVFormat(void)
 {
+#if (QT_VERSION < 0x50400)
 	// Specify the format and create platform-specific surface
-#if (QT_VERSION >= 0x50400) && defined(QOPENGLWIDGET)
-	int Samples = QSurfaceFormat::defaultFormat().samples();
-	ldvFormat.setSamples(Samples > 0 ? Samples : 1);
-	QSurfaceFormat::setDefaultFormat(ldvFormat);
-#else
 	int Samples = (QGLFormat::defaultFormat().sampleBuffers()) ? QGLFormat::defaultFormat().samples() : 1;
 	ldvFormat.setSamples(Samples);
 	ldvFormat.setAlpha(true);
@@ -484,6 +498,7 @@ void LDVWidget::setupLDVFormat(void)
 
 void LDVWidget::setupLDVContext()
 {
+#if (QT_VERSION < 0x50400)
 	bool needsInitialize = false;
 
 	ldvContext = context();
@@ -501,13 +516,9 @@ void LDVWidget::setupLDVContext()
 
 	if (needsInitialize)
 	{
-#if (QT_VERSION >= 0x50400) && defined(QOPENGLWIDGET)
-		initializeOpenGLFunctions();
-#else
 		initializeGLFunctions();
-#endif
-		//displayGLExtensions();
 	}
+#endif
 }
 
 bool LDVWidget::grabImage(int &imageWidth,
